@@ -13,7 +13,6 @@ from neurora.stuff import fwe_correct, fdr_correct, cluster_fwe_correct, cluster
     mask_to
 from neurora.rsa_plot import plot_brainrsa_rlts
 
-
 ' a function for saving the searchlight correlation coefficients as a NIfTI file for fMRI '
 
 def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60, 60, 60], ksize=[3, 3, 3], strides=[1, 1, 1], p=1, r=0, correct_method=None, smooth=True, plotrlt=True, img_background=None):
@@ -98,6 +97,8 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
     n_y = np.shape(corrs)[1]
     n_z = np.shape(corrs)[2]
 
+    corrsr = corrs[:, :, :, 0]
+
     # initialize the indexes to record the number of valid values for each voxel
     index = np.zeros([nx, ny, nz], dtype=np.int)
 
@@ -114,7 +115,7 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
                 y = j*sy
                 z = k*sz
 
-                if (math.isnan(corrs[i, j, k, 0]) == False):
+                if (math.isnan(corrsr[i, j, k]) == False):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
@@ -150,27 +151,19 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
                 z = k * sz
 
                 # p-values<threshold-p & r-values>threshold-r
-                if (corrsp[i, j, k] < p) and (corrs[i, j, k, 0] > r):
+                if (corrsp[i, j, k] < p) and (corrsr[i, j, k] > r):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
                             for k3 in range(kz):
                                 mask[x + k1, y + k2, z + k3] = 1
 
-    # sum of valid values in each calculation units
-    for i in range(n_x):
-        for j in range(n_y):
-            for k in range(n_z):
-                x = i*sx
-                y = j*sy
-                z = k*sz
-
-                if (math.isnan(corrs[i, j, k, 0]) == False):
+                if (math.isnan(corrsr[i, j, k]) == False):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
                             for k3 in range(kz):
-                                img_nii[x+k1, y+k2, z+k3] = img_nii[x+k1, y+k2, z+k3] + corrs[i, j, k, 0]
+                                img_nii[x+k1, y+k2, z+k3] = img_nii[x+k1, y+k2, z+k3] + corrsr[i, j, k]
 
     # initialize the newimg array to calculate the avg-r-value for each voxel
     newimg_nii = np.full([nx, ny, nz], np.nan)
@@ -338,41 +331,35 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
     # initialize the img array to save the sum-r-value for each voxel
     img_nii = np.zeros([nx, ny, nz], dtype=np.float64)
 
-    # iterate through all the calculation units
-
-    # calculate the indexs
-    for i in range(n_x):
-        for j in range(n_y):
-            for k in range(n_z):
-                x = i*sx
-                y = j*sy
-                z = k*sz
-
-                if (math.isnan(corrs[i, j, k, 0]) == False):
-
-                    for k1 in range(kx):
-                        for k2 in range(ky):
-                            for k3 in range(kz):
-                                index[x+k1, y+k2, z+k3] = index[x+k1, y+k2, z+k3] + 1
-
     # initialize a mask in order to record valid voxels (have qualified results)
     mask = np.zeros([nx, ny, nz], dtype=np.int)
 
     # get the p-values
     corrsp = corrs[:, :, :, 1]
+    corrsr = corrs[:, :, :, 0]
 
     # calculate the number of voxels for correction
     fadeimg = np.zeros([nx, ny, nz], dtype=np.int)
+
+    # iterate through all the calculation units
+
+    # calculate the indexs
     for i in range(n_x):
+        print(i)
         for j in range(n_y):
             for k in range(n_z):
-                x = i * sx
-                y = j * sy
-                z = k * sz
 
-                # p-values<threshold-p
+                x = i*sx
+                y = j*sy
+                z = k*sz
+
+                if corrsp[i, j, k] < 1:
+                    for k1 in range(kx):
+                        for k2 in range(ky):
+                            for k3 in range(kz):
+                                index[x+k1, y+k2, z+k3] = index[x+k1, y+k2, z+k3] + 1
+                                img_nii[x + k1, y + k2, z + k3] = img_nii[x + k1, y + k2, z + k3] + corrsr[i, j, k]
                 if corrsp[i, j, k] < p:
-
                     for k1 in range(kx):
                         for k2 in range(ky):
                             for k3 in range(kz):
@@ -408,16 +395,17 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
 
     # iterate through all the calculation units again
 
-    # record the valid voxels
-    # [n_x, n_y, n_z] expanses into [nx, ny, nz] based on ksize & strides
+    print("record the valid voxels")
+
     for i in range(n_x):
+        print(i)
         for j in range(n_y):
             for k in range(n_z):
+
                 x = i * sx
                 y = j * sy
                 z = k * sz
 
-                # p-values<threshold-p
                 if corrsp[i, j, k] < p:
 
                     for k1 in range(kx):
@@ -425,37 +413,12 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
                             for k3 in range(kz):
                                 mask[x + k1, y + k2, z + k3] = 1
 
-    # sum of valid values in each calculation units
-    for i in range(n_x):
-        for j in range(n_y):
-            for k in range(n_z):
-                x = i*sx
-                y = j*sy
-                z = k*sz
-
-                if (math.isnan(corrs[i, j, k, 0]) == False):
-
-                    for k1 in range(kx):
-                        for k2 in range(ky):
-                            for k3 in range(kz):
-                                img_nii[x+k1, y+k2, z+k3] = img_nii[x+k1, y+k2, z+k3] + corrs[i, j, k, 0]
-
     # initialize the newimg array to calculate the avg-r-value for each voxel
     newimg_nii = np.full([nx, ny, nz], np.nan)
 
     t_threshold = t.isf(p, df)
     print(t_threshold)
 
-    # calculate the avg values of each valid voxel
-    for i in range(nx):
-        for j in range(ny):
-            for k in range(nz):
-
-                # valid voxel
-                if mask[i, j, k] == 1:
-                    # sum-r-value/index
-                    newimg_nii[i, j, k] = float(img_nii[i, j, k]/index[i, j, k])
-
     # set filename for result .nii file
     if filename == None:
         filename = "rsa_result.nii"
@@ -473,45 +436,47 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
     if corr_mask == get_HOcort():
 
         mask_to(get_bg_ch2bet(), size, affine, filename)
-        mask = nib.load(filename).get_fdata()
+        cmask = nib.load(filename).get_fdata()
 
     else:
         # load the array data of the mask file
-        mask = nib.load(corr_mask).get_fdata()
+        cmask = nib.load(corr_mask).get_fdata()
 
-    # do correction by the mask
-    if corr_mask != None:
-        for i in range(nx):
-            for j in range(ny):
-                for k in range(nz):
-                    if (math.isnan(mask[i, j, k]) == True) or mask[i, j, k] == 0:
-                        newimg_nii[i, j, k] = np.nan
-                    if newimg_nii[i, j, k] < t_threshold and newimg_nii[i, j, k] > 0:
-                        newimg_nii[i, j, k] = np.nan
-                    if newimg_nii[i, j, k] > -t_threshold and newimg_nii[i, j, k] < 0:
+    # calculate the avg values of each valid voxel
+    for i in range(nx):
+        for j in range(ny):
+            for k in range(nz):
+
+                # valid voxel
+                if (math.isnan(cmask[i, j, k]) == False) and cmask[i, j, k] != 0 and mask[i, j, k] == 1:
+                    # sum-r-value/index
+                    newimg_nii[i, j, k] = float(img_nii[i, j, k]/index[i, j, k])
+                    if newimg_nii[i, j, k] < t_threshold:
                         newimg_nii[i, j, k] = np.nan
 
+    print("get RSA results")
+
     print(filename)
 
+    print("save RSA results")
 
     # save the .nii file for RSA results
     file = nib.Nifti1Image(newimg_nii, affine)
 
 
     if smooth == True:
+        print("smooth the results")
         # smooth the img data of the .nii file
         file = smooth_img(file, fwhm='fast')
 
     # save the result
     nib.save(file, filename)
 
-
     # determine if it has results
     norlt = np.isnan(newimg_nii).all()
     if norlt == True:
         print("No RSA result.")
 
-
     # determine plot the results or not
     if norlt == False and plotrlt == True:
         plot_brainrsa_rlts(filename, background=img_background, type='t')
