@@ -7,6 +7,7 @@ __author__ = 'Zitong Lu'
 import numpy as np
 from scipy.stats import pearsonr
 import math
+from neurora.stuff import show_progressbar
 
 np.seterr(divide='ignore', invalid='ignore')
 
@@ -30,7 +31,7 @@ def nps(data, time_win=5, time_step=5, sub_opt=1):
         If time_win=5, that means each calculation process based on 5 time-points.
     time_step : int. Default is 5.
         The time step size for each time of calculating.
-    sub_opt : int 0 or 1. Default is 0.
+    sub_opt : int 0 or 1. Default is 1.
         Calculate the NPS for each subject or not.
         If sub_opt=0, calculate the NPS based on all data.
         If sub_opt=1, calculate the NPS based on each subject's data
@@ -46,8 +47,12 @@ def nps(data, time_win=5, time_step=5, sub_opt=1):
 
     if len(np.shape(data)) != 5 or np.shape(data)[0] != 2:
 
+        print("\nThe shape of input should be [2, n_subs, n_trials, n_chls, n_ts].\n")
+
         return "Invalid input!"
 
+    print("\nComputing NPS")
+
     # get the number of subjects, trials, channels & time-points
     nsubs, ntrials, nchls, nts = data.shape[1:]
 
@@ -57,11 +62,18 @@ def nps(data, time_win=5, time_step=5, sub_opt=1):
     # initialize the NPS
     nps = np.zeros([nsubs, nchls, ts, 2])
 
+    total = nsubs * nchls * ts
+
     # [2, n_subs, n_trials, n_chls, n_ts]
     # calculate the NPS
     for sub in range(nsubs):
         for i in range(nchls):
             for j in range(ts):
+
+                # show the progressbar
+                percent = (sub * nchls * ts + i * ts + j) / total * 100
+                show_progressbar("Calculating", percent)
+
                 data1 = data[0, sub, :, i, j * time_step:j * time_step + time_win]
                 data2 = data[1, sub, :, i, j * time_step:j * time_step + time_win]
                 data1 = np.reshape(data1, [ntrials * time_win])
@@ -72,12 +84,16 @@ def nps(data, time_win=5, time_step=5, sub_opt=1):
     # sub_opt=1
     if sub_opt == 1:
 
+        print("\nComputing finished!")
+
         return nps
 
     elif sub_opt == 0:
 
         nps = np.average(nps, axis=0)
 
+        print("\nComputing finished!")
+
         return nps
 
 
@@ -114,8 +130,18 @@ def nps_fmri(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1]):
 
     if len(np.shape(fmri_data)) != 5 or np.shape(fmri_data)[0] != 2:
 
+        print("\nThe shape of input should be [2, n_subs, nx, ny, nz].\n")
+
         return "Invalid input!"
 
+    if kx+ky+kz < 9:
+
+        print("\nThe size of the calculation units is too small.\n")
+
+        return "Invalid size of ksize!"
+
+    print("\nComputing NPS")
+
     # get the number of subjects and the size of the fMRI-img
     nsubs, nx, ny, nz = np.shape(fmri_data)[1:]
 
@@ -164,17 +190,25 @@ def nps_fmri(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1]):
     # initialize the NPS
     subnps = np.full([nsubs, n_x, n_y, n_z, 2], np.nan)
 
+    total = nsubs * n_x * n_y * n_z
+
     # calculate the NPS
     for sub in range(nsubs):
         for x in range(n_x):
             for y in range(n_y):
                 for z in range(n_z):
 
+                    # show the progressbar
+                    percent = (sub * n_x * n_y * n_z + x * n_y * n_z + y * n_z + z) / total * 100
+                    show_progressbar("Calculating", percent)
+
                     # no NaN
                     if (np.isnan(data[:, x, y, z, 0]).any() == False) and (np.isnan(data[:, x, y, z, 1]).any() == False):
                         # calculate the Pearson Coefficient and absolute the result
                         subnps[sub, x, y, z] = pearsonr(data[sub, x, y, z, 0], data[sub, x, y, z, 1])
 
+    print("\nComputing finished!")
+
     return subnps
 
 ' a function for calculating the neural pattern similarity for fMRI data (for ROI) '
@@ -206,10 +240,20 @@ def nps_fmri_roi(fmri_data, mask_data):
     The size of the calculation units should at least be [3, 3, 3].
     """
 
-    if len(np.shape(fmri_data)) != 5 or np.shape(fmri_data)[0] != 2 or len(np.shape(mask_data)) != 3:
+    if len(np.shape(fmri_data)) != 5 or np.shape(fmri_data)[0] != 2:
+
+        print("\nThe shape of fmri data should be [2, n_subs, nx, ny, nz].\n")
 
         return "Invalid input!"
 
+    if len(np.shape(mask_data)) != 3:
+
+        print("\nThe shape of fmri data should be [nx, ny, nz].\n")
+
+        return "Invalid input!"
+
+    print("\nComputing NPS")
+
     # get the number of subjects and the size of the fMRI-img
     nsubs, nx, ny, nz = fmri_data.shape[1:]
 
@@ -252,4 +296,6 @@ def nps_fmri_roi(fmri_data, mask_data):
     for sub in range(nsubs):
         subnps[sub] = pearsonr(data[sub, 0], data[sub, 1])
 
+    print("\nComputing finished!")
+
     return subnps
\ No newline at end of file
